summaryrefslogtreecommitdiffstats
path: root/tdehtml/ecma/kjs_debugwin.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
commit7427e438358d44c37e3c8b0a9cfbb225ffd60e79 (patch)
treed977f1d23d324f23aadee0ad50acb94d7436ba80 /tdehtml/ecma/kjs_debugwin.cpp
parent72eecb041bf15bf64b748fc062d55f6ec860ac60 (diff)
downloadtdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.tar.gz
tdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.zip
Rename KHTML and kiobuffer
Diffstat (limited to 'tdehtml/ecma/kjs_debugwin.cpp')
-rw-r--r--tdehtml/ecma/kjs_debugwin.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdehtml/ecma/kjs_debugwin.cpp b/tdehtml/ecma/kjs_debugwin.cpp
index 47921fb2a..ec794b8d2 100644
--- a/tdehtml/ecma/kjs_debugwin.cpp
+++ b/tdehtml/ecma/kjs_debugwin.cpp
@@ -249,12 +249,12 @@ KJSDebugWin * KJSDebugWin::kjs_html_debugger = 0;
TQString SourceFile::getCode()
{
if (interpreter) {
- KHTMLPart *part = ::tqqt_cast<KHTMLPart*>(static_cast<ScriptInterpreter*>(interpreter)->part());
- if (part && url == part->url().url() && KHTMLPageCache::self()->isValid(part->cacheId())) {
+ TDEHTMLPart *part = ::tqqt_cast<TDEHTMLPart*>(static_cast<ScriptInterpreter*>(interpreter)->part());
+ if (part && url == part->url().url() && TDEHTMLPageCache::self()->isValid(part->cacheId())) {
Decoder *decoder = part->createDecoder();
TQByteArray data;
TQDataStream stream(data,IO_WriteOnly);
- KHTMLPageCache::self()->saveData(part->cacheId(),&stream);
+ TDEHTMLPageCache::self()->saveData(part->cacheId(),&stream);
TQString str;
if (data.size() == 0)
str = "";
@@ -721,7 +721,7 @@ bool KJSDebugWin::sourceParsed(KJS::ExecState *exec, int sourceId,
KParts::ReadOnlyPart *part = static_cast<ScriptInterpreter*>(exec->interpreter())->part();
if (m_nextSourceUrl == part->url().url()) {
// Only store the code here if it's not from the part's html page... in that
// case we can get it from KHTMLPageCache
code = TQString::null;
}
@@ -805,7 +805,7 @@ bool KJSDebugWin::exception(ExecState *exec, const Value &value, bool inTryCatch
return true;
KParts::ReadOnlyPart *part = static_cast<ScriptInterpreter*>(exec->interpreter())->part();
- KHTMLPart *tdehtmlpart = ::tqqt_cast<KHTMLPart*>(part);
+ TDEHTMLPart *tdehtmlpart = ::tqqt_cast<TDEHTMLPart*>(part);
if (tdehtmlpart && !tdehtmlpart->settings()->isJavaScriptErrorReportingEnabled())
return true;
@@ -721,7 +721,7 @@ bool KJSDebugWin::sourceParsed(KJS::ExecState *exec, int sourceId,
if (m_nextSourceUrl == part->url().url()) {
// Only store the code here if it's not from the part's html page... in that
- // case we can get it from KHTMLPageCache
+ // case we can get it from TDEHTMLPageCache
code = TQString::null;
}